
/*July 8, 2009*/

/*THIS PROGRAM CONSTRUCTS THE 2000 THBS ANALYSIS SAMPLE, analysis_samp_thbs_2000.dta, FROM VARIOUS RAW FILES.
THE RAW FILES USED TO CREATE THE ANALYSIS SAMPLE ARE:

Tanzanian Household Budget Survey modules:
1. "export2_1b.dta"
2. "export1_1.dta"
3. "export3_1.dta"
4. "districts.dta"
(subset of raw file: "export8_1.dta")
5." schooldist.dta" 
(reshaped subset of raw file "export6_1")

World Health organization data on goiter:
6. "tgr.dta"

Program data on iodine intervention:
7. "intdistsDHS04.txt"

Subset of 2004 Demographic and Health Survey:
8. "TanzaniaDHS.dta"


*/

clear
set mem 120m
#delimit ;
set logtype text;
set more on;

/*cd XXXXX;*/


/*First clean and collect household-level data on SES from raw file "export1_1.dta", generates "sec1vars.dta"*/

use export1_1.dta;

rename s6q77 foodneed;
replace foodneed=0 if foodneed<3;
replace foodneed=1 if foodneed>0;
gen flush=(s32q05==2);
rename s6q64 land;
gen elec=(s32q02a==1);
keep hhmonth foodneed hhid urb flush land elec;
sort hhid; 
save sec1vars.dta, replace;

/*Second clean and collect individual-level data on head and spouse from raw file "export2_1b.dta", generates "sec2vars.dta"*/

use export2_1b.dta;
gen eh=s2q07e if s2q02==1;
gen es=s2q07e if s2q02==2;
replace eh=17 if eh==17|eh==18|eh==19|eh==21;
replace eh=18 if eh==20;
replace eh=0 if eh==22;

replace es=17 if es==17|es==18|es==19|es==21;
replace es=18 if es==20;
replace es=0 if es==22;

egen edhd=max(eh), by(hhid);
egen edsp=max(es), by(hhid);
egen hid=tag(hhid);
keep if hid==1;
keep edhd edsp hhid;
sort hhid; 
save sec2vars.dta, replace;

/*Third clean and collect household-level data on SES from raw file "export3_1.dta", generates "sec3vars.dta*/

use export3_1.dta;
gen ownhome=(s31q13==1);
gen mudfloor=(s31q09==1);
gen grassroof=(s31q12==1| s31q12==2);
rename s31q05 rooms; 
egen maxoh=max(ownh), by(hhid);
replace ownh=maxoh;
egen maxgr=max(grassr), by(hhid);
replace grassr=maxgr;
keep ownhome mudfloor grassroof rooms hhid;
sort hhid; 
save sec3vars.dta, replace;

/*Fourth clean district-level data on baseline rates of goiter collected in the 1980s (uses "tgr_raw.dta, generates tgr.dta)*/
use tgr_raw.dta, clear;

/*Create measure of TGR that combines rates of TGR1 and TGR2*/
gen tgr12=g1tgr+g2tgr;
replace tgr12=. if g1tgr==.|g2tgr==.;
sort geocode;
save tgr.dta, replace;

/*Fifth use 2004 DHS sample of kids under 8 to generate seasonality in births for adjusting probability measures of program participation (file "TanzaniaDHS.dta, generate "seas.dta*/;

use TanzaniaDHS.dta, clear;
keep if age<8&age~=.;
drop if birthm==.;
rename birthmonth bm;
sort region;

/*seasonality variable*/
gen one=1 ;
sort region;
egen dispop=sum(one), by(region);
replace dispop=dispop/12;

forvalues X = 1/12 {;
gen m`X'=bm==`X';
egen dism`X'=sum(m`X'), by(region);
replace dism`X'=dism`X'/dispop;
};

egen tag=tag(region bm);
keep if tag==1;
keep dism* region;
sort region;
keep dism* region;
sort region;

save seas.dta, replace;

/*Sixth convert data on program rounds by district to Stata files with coverage by age and year of distribution round by district (Table 1 of the paper, file "intdistsDHS04.txt", generate "pf.dta, "cov.dta*/;

insheet using "intdistsDHS04.txt", clear;
keep geocode year1 year2 year3 year4 year5;
sort geocode;
save pf.dta, replace;

insheet using "intdistsDHS04.txt", clear;
drop coverage*;
keep geocode cov* avgcov*;
reshape long cov avgcov, i(geocode) j(age);
replace cov=cov/100;

sort geocode age;
save cov.dta, replace;


/*Seventh, create THBS analysis sample by collecting and cleaning individual data on kids from raw THBS file, export2_1)*/;

use export2_1b.dta, clear;
rename s2q03 sex;
rename s2q07b inschool;
rename s2q07d currgrade;
recode inschool 2=0;
gen litt=(s2q07a>0&s2q07a<5);
recode sex 2=0;
rename s2q04 age;
gen age1013=age if age>9 & age<14;
gen age1014=age if age>9 & age<15;
gen agef=age if sex==0;
gen agem=age if sex==1;
gen urb=(urb_==1);
rename s2q07e grade;
recode grade 22=0;

/*Correct error in which form 4 (grade 12) entered instead of standard 4 (one ob)*/;
replace grade=4 if grade==12&age==13;

/* =1 if in primary school */

gen ins2=1 if inschool==1|(grade>0&grade~=.)|(higheduc>2&higheduc~=.);
recode ins2 .=0;
replace ins2=0 if currgrade==0;
replace ins2=1 if currgrade>0&currgrade~=.;

gen ins2b=1 if inschool==1|(grade>0&grade~=.)|(higheduc>1&higheduc~=.);
recode ins2b .=0;
replace ins2b=1 if currgrade~=.;

/*=1 if passed 1st standard*/
gen ins3=1 if grade>0 &grade~=.;
recode ins3 .=0;

/*=1 if passed 2nd standard*/

gen ins4=1 if grade>1 &grade~=.;
recode ins4 .=0;

/*=1 if passed 3rd standard*/

gen ins5=1 if grade>2 &grade~=.;
recode ins5 .=0;
/*=1 if passed 4th standard*/

gen ins6=1 if grade>3 &grade~=.;
recode ins6 .=0;

gen ins7=1 if grade>4 &grade~=.;
replace ins7=1 if highe>3&highed~=.;
recode ins7 .=0;

replace ins3=. if grade==.;
replace ins4=. if grade==.;
replace ins2=. if grade==.;
replace ins2b=. if grade==.;

replace ins5=. if grade==.;
replace ins6=. if grade==.;
replace ins7=. if grade==.;

/*Creating mother's age variable*/
gen kidhd=(s2q02>2&s2q02<6);
gen kidspouse=(s2q02==5);
gen spouse=(s2q02==2);
gen fspouse=(spouse==1 & sex==0);
gen fhead= (s2q02==1 & sex==0);

/*determining number of spouses, sequencing spouses*/
egen numfspouse=sum(fspouse), by(hhid);
tab numfspouse;
gsort hhid fspouse -age;
egen fspouseseq= seq(), by(hhid fspouse);
replace fspouseseq=. if fspouse==0;
gen fheadage=age if fhead==1;
egen fhage=max(fheadage), by(hhid);
gen fspouseage1=age if fspouse==1 & fspouseseq==1;
egen fsage1=max(fspouseage1), by(hhid);
gen fspouseage2=age if fspouse==1 & fspouseseq==2;
egen fsage2=max(fspouseage2), by(hhid);
gen fspouseage3=age if fspouse==1 & fspouseseq==3;
egen fsage3=max(fspouseage3), by(hhid);
gen fspouseage4=age if fspouse==1 & fspouseseq==4;
egen fsage4=max(fspouseage4), by(hhid);
gen fspouseage5=age if fspouse==1 & fspouseseq==5;
egen fsage5=max(fspouseage5), by(hhid);
gen fspouseage6=age if fspouse==1 & fspouseseq==6;
egen fsage6=max(fspouseage6), by(hhid);
gen fspouseage7=age if fspouse==1 & fspouseseq==7;
egen fsage7=max(fspouseage7), by(hhid);
gen fspouseage8=age if fspouse==1 & fspouseseq==8;
egen fsage8=max(fspouseage8), by(hhid);

/*Keep kids and grandkids of head only*/;
gen hdrel=(s2q02>2&s2q02<7);
keep if hdrel;
gen relhd=s2q02;

/*Note: want to drop obs other than hdrel before computing birth orders*/;
keep if age>5&age<14;
sort hhid -age;
egen bo=seq(), by(hhid);
sort hhid -agem;
egen ssbo=seq() if sex==1, by(hhid);
sort hhid -agef;
egen ssbof=seq() if sex==0, by(hhid);
replace ssbo=ssbof if sex==0;

/*Get district IDs from subset of larger THBS file (file districts is a subset of file export8_1.dta)*/;
sort hhid;
merge hhid using districts.dta;
keep if _merge==3;
drop _merge;
gen geocode=(region*10)+dist;

/*Drop 2 late program districts (182 & 103)*/;
keep if geocode~=182 &geocode~=103;
egen one=tag(hhid);
egen distpop=sum(one), by(geocode);

/*Assigning mom's age*/
/*mom age identified if child is kid of head and head is female*/
gen momage=fhage if kidhd==1 & fhage~=.;

/*mom age identified if child is kid of male head and only 1 spouse*/
replace momage=fsage1 if kidhd==1 & fhage==. & fsage2==.;

/*Dealing with polygamy- mom age identified if child is kid of male head and only 1 spouse in correct age range*/
summ fsage*;
drop fsage5-fsage8;
gen fsageatb1= ((fsage1-age)>11 & (fsage1-age)<46);
gen fsageatb2= ((fsage2-age)>11 & (fsage2-age)<46);
gen fsageatb3= ((fsage3-age)>11 & (fsage3-age)<46);
gen fsageatb4= ((fsage4-age)>11 & (fsage4-age)<46);
gen numeligmom= fsageatb1+fsageatb2+fsageatb3+fsageatb4;
replace momage=fsage1 if momage==. & fsageatb1==1 & numeligmom==1;
replace momage=fsage2 if momage==. & fsageatb2==1 & numeligmom==1;
replace momage=fsage3 if momage==. & fsageatb3==1 & numeligmom==1;
replace momage=fsage4 if momage==. & fsageatb4==1 & numeligmom==1;

/*mom's age to missing if kid is grandchild of head*/
replace momage=. if kidhd==0;

/*creating variable for mom's age at birth, replace with missing if age unreasonable*/
gen momageatb= momage-age;
replace momage=. if momageatb<12 | momageatb>45;
replace momageatb=. if momageatb<11 | momageatb>45;

/*creating young mother (under 23) variable*/
gen my=(momageatb<24);
replace my=. if momageatb==.;
gen nomage=my==.;

/*sick variables*/;
forvalues X = 1/8 {;
recode s2r10_`X' .=0;
};

recode s2q09  2=0;
replace s2q11=s2q11-1;
recode s2q11 .=0;
recode s2q12 2=0;
rename s2q09 sick;
rename s2q11 sickdays;
rename s2q12 doctor;
rename s2r10_1 fever;
rename s2r10_2 diarrhea;
rename s2r10_3 accident;
rename s2r10_4 dental;
rename s2r10_5 skin;
rename s2r10_6 eye;
rename s2r10_7 ear_nose_throat;
rename s2r10_8 other;

keep bo ssbo grade age age10* sick* doctor* ear eye skin relhd dental diarrhea fever accident nomage other indid hdrel hhid geocode sex litt inschool currgrade ins2* ins3 ins4 ins5 ins6 ins2b ins7 urb momage momageatb my kidhd higheduc curr*;

sort indid;
tab age1014, gen(dage);

rename dage1 dage10;
rename dage2 dage11;
rename dage3 dage12;
rename dage4 dage13;

sort hhid;

merge hhid using schooldist.dta, update;
keep if _merge~=2;
drop _merge;

save temp_2000.dta, replace;
sort geocode;
merge geocode using pf.dta;

recode year1 .=0;
recode year2 .=0;
recode year3 .=0;
recode year4 .=0;
recode year5 .=0;
gen pd=year1~=0;
keep if pd==1;
drop if _merge==2;
drop _merge;

gen region=int(geocode/10);
sort region;
merge region using seas.dta;
drop _merge;
sort hhid age;

replace sex=1-sex;

/*Eight, generate program indicator*/

gen late0=0;
gen late1=0;
gen late2=0;
gen late3=0;
gen late4=0;

/*First step: use monthly probabilities in Appendix A adjusted for monthly birth seasonality from DHS (dism*) to create probability of treatment in year t relative to program year (t0-t4)*/;

/* Seasonality has to be multiplied by probability that you are born*/
gen t0=(1/12)*[(dism1*0)+(dism2*0)+(dism3*0)+(dism4*0)+(dism5*0)+(dism6*0)+ (dism7*0)+ (dism8*0.028)+(dism9*0.083)+(dism10*0.167)+(dism11*0.250)+(dism12*0.333)];

gen t1=(1/12)*[(dism1*0.417)+(dism2*0.5)+(dism3*0.583)+(dism4*0.667)+ (dism5*0.75)+ (dism6*0.833)+ (dism7*0.917)+ (dism8*1)+(dism9*1)+(dism10*1)+(dism11*1)+(dism12*1)];

gen t2=(1/12)*[(dism1*1)+(dism2*1)+(dism3*1)+(dism4*1)+ (dism5*1)+ (dism6*1)+ (dism7*1)+ (dism8*1)+(dism9*1)+(dism10*0.998)+(dism11*0.991)+(dism12*0.977)];

gen t3=(1/12)*[(dism1*0.955)+(dism2*0.927)+(dism3*0.891)+(dism4*0.849)+ (dism5*0.802)+ (dism6*0.749)+ (dism7*0.690)+ (dism8*0.627)+(dism9*0.559)+(dism10*0.488)+(dism11*0.419)+(dism12*0.353)];

gen t4=(1/12)*[(dism1*0.292)+(dism2*0.237)+(dism3*0.189)+(dism4*0.148)+ (dism5*0.112)+ (dism6*0.082)+ (dism7*0.057)+ (dism8*0.037)+(dism9*0.022)+(dism10*0.011)+(dism11*0.004)+(dism12*0.001)];

/*Second step: Assign a probability value (either t0, t1, t2, t3, t4 or 0) for each possible program year (1986-1994) to each cohort ages 6-13 based on district program years (captured in variables year1  year5). In other words, p86, which varies by age and district, is the probability that a kid was protected by a distribution round in 1986. Since kids 6-9 were born too late to be affected by what happened in 1986, they are assigned a value of 0 for p86 regardless of what happened in the district*/; 

/*The late variables (late0-late4), are dummy indicators of how close to the nearest distribution round a kid was born*/;

gen p86=0 if age==6&(year1==1986|year2==1986|year3==1986|year4==1986|year5==1986);

replace p86=0 if age==7&(year1==1986|year2==1986|year3==1986|year4==1986|year5==1986);

replace p86=0 if age==8&(year1==1986|year2==1986|year3==1986|year4==1986|year5==1986);

replace p86=0 if age==9&(year1==1986|year2==1986|year3==1986|year4==1986|year5==1986);


replace p86=t4 if age==10&(year1==1986|year2==1986|year3==1986|year4==1986|year5==1986);

replace late4=1 if age==10&(year1==1986|year2==1986|year3==1986|year4==1986|year5==1986);

replace p86=t3 if age==11&(year1==1986|year2==1986|year3==1986|year4==1986|year5==1986);

replace late3=1 if age==11&(year1==1986|year2==1986|year3==1986|year4==1986|year5==1986);

replace p86=t2 if age==12&(year1==1986|year2==1986|year3==1986|year4==1986|year5==1986);

replace late2=1 if age==12&(year1==1986|year2==1986|year3==1986|year4==1986|year5==1986);

replace p86=t1 if age==13&(year1==1986|year2==1986|year3==1986|year4==1986|year5==1986);

recode p86 .=0;

replace late1=1 if age==13&(year1==1986|year2==1986|year3==1986|year4==1986|year5==1986);

recode p86 .=0;

gen p87=0 if age==6&(year1==1987|year2==1987|year3==1987|year4==1987|year5==1987);

replace p87=0 if age==7&(year1==1987|year2==1987|year3==1987|year4==1987|year5==1987);

replace p87=0 if age==8&(year1==1987|year2==1987|year3==1987|year4==1987|year5==1987);

replace p87=t4 if age==9&(year1==1987|year2==1987|year3==1987|year4==1987|year5==1987);

replace late4=1 if age==9&(year1==1987|year2==1987|year3==1987|year4==1987|year5==1987);

replace p87=t3 if age==10&(year1==1987|year2==1987|year3==1987|year4==1987|year5==1987);

replace late3=1 if age==10&(year1==1987|year2==1987|year3==1987|year4==1987|year5==1987);

replace p87=t2 if age==11&(year1==1987|year2==1987|year3==1987|year4==1987|year5==1987);

replace late2=1 if age==11&(year1==1987|year2==1987|year3==1987|year4==1987|year5==1987);

replace p87=t1 if age==12&(year1==1987|year2==1987|year3==1987|year4==1987|year5==1987);

replace late1=1 if age==12&(year1==1987|year2==1987|year3==1987|year4==1987|year5==1987);
replace p87=t0 if age==13&(year1==1987|year2==1987|year3==1987|year4==1987|year5==1987);

recode p87 .=0;

replace late0=1 if age==13&(year1==1987|year2==1987|year3==1987|year4==1987|year5==1987);

recode p87 .=0;

gen p88=0 if age==6&(year1==1988|year2==1988|year3==1988|year4==1988|year5==1988);

replace p88=0 if age==7&(year1==1988|year2==1988|year3==1988|year4==1988|year5==1988);


replace p88=t4 if age==8&(year1==1988|year2==1988|year3==1988|year4==1988|year5==1988);


replace p88=t3 if age==9&(year1==1988|year2==1988|year3==1988|year4==1988|year5==1988);

replace late4=1 if age==8&(year1==1988|year2==1988|year3==1988|year4==1988|year5==1988);

replace late3=1 if age==9&(year1==1988|year2==1988|year3==1988|year4==1988|year5==1988);

replace p88=t2 if age==10&(year1==1988|year2==1988|year3==1988|year4==1988|year5==1988);

replace late2=1 if age==10&(year1==1988|year2==1988|year3==1988|year4==1988|year5==1988);

replace p88=t1 if age==11&(year1==1988|year2==1988|year3==1988|year4==1988|year5==1988);

replace p88=t0 if age==12&(year1==1988|year2==1988|year3==1988|year4==1988|year5==1988);

replace late1=1 if age==11&(year1==1988|year2==1988|year3==1988|year4==1988|year5==1988);

replace late0=1 if age==12&(year1==1988|year2==1988|year3==1988|year4==1988|year5==1988);

replace p88=0 if age==13&(year1==1988|year2==1988|year3==1988|year4==1988|year5==1988);

recode p88 .=0;

gen p89=0 if age==6&(year1==1989|year2==1989|year3==1989|year4==1989|year5==1989);

replace p89=t4 if age==7&(year1==1989|year2==1989|year3==1989|year4==1989|year5==1989);
replace p89=t3 if age==8&(year1==1989|year2==1989|year3==1989|year4==1989|year5==1989);

replace late4=1 if age==7&(year1==1989|year2==1989|year3==1989|year4==1989|year5==1989);

replace late3=1 if age==8&(year1==1989|year2==1989|year3==1989|year4==1989|year5==1989);

replace p89=t2 if age==9&(year1==1989|year2==1989|year3==1989|year4==1989|year5==1989);

replace late2=1 if age==9&(year1==1989|year2==1989|year3==1989|year4==1989|year5==1989);

replace p89=t1 if age==10&(year1==1989|year2==1989|year3==1989|year4==1989|year5==1989);

replace p89=t0 if age==11&(year1==1989|year2==1989|year3==1989|year4==1989|year5==1989);

replace late1=1 if age==10&(year1==1989|year2==1989|year3==1989|year4==1989|year5==1989);

replace late0=1 if age==11&(year1==1989|year2==1989|year3==1989|year4==1989|year5==1989);

replace p89=0 if age==12&(year1==1989|year2==1989|year3==1989|year4==1989|year5==1989);

replace p89=0 if age==13&(year1==1989|year2==1989|year3==1989|year4==1989|year5==1989);

recode p89 .=0;

gen p90=t4 if age==6&(year1==1990|year2==1990|year3==1990|year4==1990|year5==1990);

replace p90=t3 if age==7&(year1==1990|year2==1990|year3==1990|year4==1990|year5==1990);

replace late4=1 if age==6&(year1==1990|year2==1990|year3==1990|year4==1990|year5==1990);

replace late3=1 if age==7&(year1==1990|year2==1990|year3==1990|year4==1990|year5==1990);

replace p90=t2 if age==8&(year1==1990|year2==1990|year3==1990|year4==1990|year5==1990);

replace late2=1 if age==8&(year1==1990|year2==1990|year3==1990|year4==1990|year5==1990);

replace p90=t1 if age==9&(year1==1990|year2==1990|year3==1990|year4==1990|year5==1990);

replace p90=t0 if age==10&(year1==1990|year2==1990|year3==1990|year4==1990|year5==1990);

replace late1=1 if age==9&(year1==1990|year2==1990|year3==1990|year4==1990|year5==1990);

replace late0=1 if age==10&(year1==1990|year2==1990|year3==1990|year4==1990|year5==1990);

replace p90=0 if age==11&(year1==1990|year2==1990|year3==1990|year4==1990|year5==1990);

replace p90=0 if age==12&(year1==1990|year2==1990|year3==1990|year4==1990|year5==1990);

replace p90=0 if age==13&(year1==1990|year2==1990|year3==1990|year4==1990|year5==1990);

recode p90 .=0;

gen p91=t3 if age==6&(year1==1991|year2==1991|year3==1991|year4==1991|year5==1991);

replace late3=1 if age==6&(year1==1991|year2==1991|year3==1991|year4==1991|year5==1991);

replace p91=t2 if age==7&(year1==1991|year2==1991|year3==1991|year4==1991|year5==1991);

replace late2=1 if age==7&(year1==1991|year2==1991|year3==1991|year4==1991|year5==1991);

replace p91=t1 if age==8&(year1==1991|year2==1991|year3==1991|year4==1991|year5==1991);

replace p91=t0 if age==9&(year1==1991|year2==1991|year3==1991|year4==1991|year5==1991);

replace late1=1 if age==8&(year1==1991|year2==1991|year3==1991|year4==1991|year5==1991);

replace late0=1 if age==9&(year1==1991|year2==1991|year3==1991|year4==1991|year5==1991);

replace p91=0 if age==10&(year1==1991|year2==1991|year3==1991|year4==1991|year5==1991);

replace p91=0 if age==11&(year1==1991|year2==1991|year3==1991|year4==1991|year5==1991);

replace p91=0 if age==12&(year1==1991|year2==1991|year3==1991|year4==1991|year5==1991);

replace p91=0 if age==13&(year1==1991|year2==1991|year3==1991|year4==1991|year5==1991);

recode p91 .=0;

gen p92=t2 if age==6&(year1==1992|year2==1992|year3==1992|year4==1992|year5==1992);

replace late2=1 if age==6&(year1==1992|year2==1992|year3==1992|year4==1992|year5==1992);

replace p92=t1 if age==7&(year1==1992|year2==1992|year3==1992|year4==1992|year5==1992);

replace p92=t0 if age==8&(year1==1992|year2==1992|year3==1992|year4==1992|year5==1992);

replace late1=1 if age==7&(year1==1992|year2==1992|year3==1992|year4==1992|year5==1992);

replace late0=1 if age==8&(year1==1992|year2==1992|year3==1992|year4==1992|year5==1992);

replace p92=0 if age==9&(year1==1992|year2==1992|year3==1992|year4==1992|year5==1992);

replace p92=0 if age==10&(year1==1992|year2==1992|year3==1992|year4==1992|year5==1992);

replace p92=0 if age==11&(year1==1992|year2==1992|year3==1992|year4==1992|year5==1992);

replace p92=0 if age==12&(year1==1992|year2==1992|year3==1992|year4==1992|year5==1992);

replace p92=0 if age==13&(year1==1992|year2==1992|year3==1992|year4==1992|year5==1992);

recode p92 .=0;

gen p93=t1 if age==6&(year1==1993|year2==1993|year3==1993|year4==1993|year5==1993);

replace p93=t0 if age==7&(year1==1993|year2==1993|year3==1993|year4==1993|year5==1993);

replace late1=1 if age==6&(year1==1993|year2==1993|year3==1993|year4==1993|year5==1993);

replace late0=1 if age==7&(year1==1993|year2==1993|year3==1993|year4==1993|year5==1993);

replace p93=0 if age==8&(year1==1993|year2==1993|year3==1993|year4==1993|year5==1993);

replace p93=0 if age==9&(year1==1993|year2==1993|year3==1993|year4==1993|year5==1993);

replace p93=0 if age==10&(year1==1993|year2==1993|year3==1993|year4==1993|year5==1993);
replace p93=0 if age==11&(year1==1993|year2==1993|year3==1993|year4==1993|year5==1993);

replace p93=0 if age==12&(year1==1993|year2==1993|year3==1993|year4==1993|year5==1993);

replace p93=0 if age==13&(year1==1993|year2==1993|year3==1993|year4==1993|year5==1993);

recode p93 .=0;

gen p94=t0 if age==6&(year1==1994|year2==1994|year3==1994|year4==1994|year5==1994);

replace late0=1 if age==6&(year1==1994|year2==1994|year3==1994|year4==1994|year5==1994);

replace p94=0 if age==7&(year1==1994|year2==1994|year3==1994|year4==1994|year5==1994);


replace p94=0 if age==8&(year1==1994|year2==1994|year3==1994|year4==1994|year5==1994);

replace p94=0 if age==9&(year1==1994|year2==1994|year3==1994|year4==1994|year5==1994);

replace p94=0 if age==10&(year1==1994|year2==1994|year3==1994|year4==1994|year5==1994);

replace p94=0 if age==11&(year1==1994|year2==1994|year3==1994|year4==1994|year5==1994);

replace p94=0 if age==12&(year1==1994|year2==1994|year3==1994|year4==1994|year5==1994);

replace p94=0 if age==13&(year1==1994|year2==1994|year3==1994|year4==1994|year5==1994);

recode p94 .=0;

/*Step 3: For each age group in each district, we aggregate the probabilities from multiple distribution rounds with max probability of 1*/

gen pr3=(p86+p87+p88+p89+p90+p91+p92+p93+p94);
replace pr3=1 if pr3>1&pr3<1000;

/*Step 4: To create the binary indicator, we assign a value of 1 to any probability over 0.4, which is equivalent to assigning a value of 1 to kids born in years 1-3 of the program (based on table in Appendix A)*/
gen pr2=pr3>0.4&pr3<1.1;

/*Here we adjust the indicator of mother under 23 at birth to reflect whether the mother was under 23 at the time of the distribution round closest to (but before) birth, since this is what matters for take-up. In other words, if a kids mother was 26 at birth but the closest distribution round happened 4 years earlier (late4=1), she is assigned a value of 1 for young mother since she was 23 at the time of distribution. */

replace my=0;
replace my=1 if momageatb<23&momageatb~=. & late0==1;
replace my=1 if momageatb<24&momageatb~=. & late1==1;
replace my=1 if momageatb<25&momageatb~=. & late2==1;
replace my=1 if momageatb<26&momageatb~=. & late3==1;
replace my=1 if momageatb<27&momageatb~=. & late4==1;

gen one=1;
egen famsize=sum(one), by(hhid);
gen hhis=hhid*10;
replace hhis=hhis+1 if sex==1;
egen nhhis=sum(one), by(hhis);
egen kids=sum(one), by(hhid);
gen girl=sex==1;
egen girls=sum(girl), by(hhid);
gen boy=sex==0;
egen boys=sum(boy), by(hhid);

recode sickdays .=0;
recode sick .=0;
recode fever .=0;
recode diarrhea .=0;
recode accident .=0;
recode skin .=0;
recode dental .=0;
recode eye .=0;
recode ear_no .=0;
recode other .=0;
recode litt .=0;

gen lateom=2 if late4==1;
replace lateom= 1 if late3==1;
recode lateom .=0;
gen lateym=2 if late4==1;
replace lateym= 1 if late3==1;
recode lateym .=0;

egen geoage=group(geocode age);

recode dage11 .=0;
recode dage12 .=0;
recode dage13 .=0;

sort geocode age;

gen origsamp=1;
sort hhid;
merge hhid using sec1vars.dta, update;
drop if _merge==2;
drop _merge;
sort hhid;
merge hhid using sec2vars.dta, update;
drop if _merge==2;
drop _merge;
sort hhid;
merge hhid using sec3vars.dta, update;
drop if _merge==2;
drop _merge;
sort geocode;
merge geocode using tgr.dta, update;
drop if _merge==2;
drop _merge;
sort geocode age;
merge geocode age using cov.dta, update;
drop if _merge==2;
drop _merge;
egen doubleid=tag(indid);
keep if doubleid==1;

/*Final cleaning*/
keep indid age nomage cov lateom pr2 tgr12 lateym my foodneed pr3 one hhid girl boy grade dage11 dage12 dage13 urb boys kids edhd edsp ssbo bo hhmonth ownhome grass foodneed distsec distcl girl geocode geoage sick fever diarr ear eye skin dental accident other sickdays sex late0 late1 late2 late3 late4 relhd ins*;

label variable urb "urban";
label variable relhd "relationship to head";
label variable bo "birth order";
label variable ssbo "sex-specific birth order";
label variable my "mother under 23 at birth";
label variable nomage "mothers age missing";
label variable dage11 "age=11";
label variable dage12 "age=12";
label variable dage13 "age=13";
label variable distclin "distance (km) nearest clinic";
label variable distsec "distance (km) nearest secondary school";
label variable edhd "education head";
label variable edsp "education spouse";
label variable geocode "district ID";
label variable cov "district coverage rate";
label variable pr2 "program indicator - binary";
label variable pr3 "program indicator - continuous";
label variable ownhome "own home";
label variable grassroof "grass roof";
label variable tgr12 "district total goiter rate 1980s";
label variable late0 "born in program year";
label variable late1 "born year after program";
label variable late2 "born 2 years after program";
label variable late3 "born 3 years after program";
label variable late4 "born 4 years after program";
label variable one "1";
label variable kids "number kids in household";
label variable girl "girl";
label variable boy "boy";
label variable boys "number boys in household";

save analysis_samp_thbs_2000.dta, replace;

